@@ -39,10 +39,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
             print("pandas.errors.EmptyDataError (phone mims) : " + csv_path)
             quit()
 
-    if len(df_logs_combined["HEADER_TIME_STAMP"][0].split(".")) > 1:
-        converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f")
-    else:
-        converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
+    converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f") if ("." in x) else datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
 
     df_logs_combined = df_logs_combined.dropna(subset=['HEADER_TIME_STAMP'])
     df_logs_combined.reset_index(inplace=True, drop=True)
@@ -94,9 +91,9 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         # prompt_date = prompt_time.date()
 
         if df_logs_combined.shape[0] == 0:
-            matched_mims_summary_list = ["NF"] * len(min_before_list)
-            matched_readings_list = ["NF"] * len(min_before_list)
-            matched_start_time_list = ["NF"] * len(min_before_list)
+            matched_mims_summary_list = [np.nan] * len(min_before_list)
+            matched_readings_list = [np.nan] * len(min_before_list)
+            matched_start_time_list = [np.nan] * len(min_before_list)
         else:
             subset_time_list = list(df_logs_combined["TIME_DATETIME"])
             pos = find_closest_time(prompt_time, subset_time_list)
