@@ -48,6 +48,7 @@ def extract_reprompt(df_pr_phone):
             new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
             new_reprompt_row.append(row["Answer_Status"])
             new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
+            new_reprompt_row.append("null")
             new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
             new_reprompt_row.append("0")
             prompt_arrays.append(new_reprompt_row)
@@ -65,6 +66,7 @@ def extract_reprompt(df_pr_phone):
                     new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
                     new_reprompt_row.append(row["Answer_Status"])
                     new_reprompt_row.append(row[reprompt_local])
+                    new_reprompt_row.append(row["Question_1_Answer_Unixtime"])
                     new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
                     new_reprompt_row.append(str(i))
                     prompt_arrays.append(new_reprompt_row)
@@ -79,12 +81,13 @@ def extract_reprompt(df_pr_phone):
                     break
 
             if last_reprompt_num == 0:
-                # init prompt
+                # init prompt completed
                 new_reprompt_row = []
                 new_reprompt_row += list(row[['Prompt_Type', 'Study_Mode']])
                 new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
                 new_reprompt_row.append(row["Answer_Status"])
                 new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
+                new_reprompt_row.append(row["Question_1_Answer_Unixtime"])
                 new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
                 new_reprompt_row.append("0")
                 prompt_arrays.append(new_reprompt_row)
@@ -99,6 +102,7 @@ def extract_reprompt(df_pr_phone):
                         new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
                         new_reprompt_row.append(status)
                         new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
+                        new_reprompt_row.append("null")
                         new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
                         new_reprompt_row.append("0")
                         prompt_arrays.append(new_reprompt_row)
@@ -118,13 +122,14 @@ def extract_reprompt(df_pr_phone):
                         new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
                         new_reprompt_row.append(status)
                         new_reprompt_row.append(row[reprompt_local])
+                        new_reprompt_row.append(row["Question_1_Answer_Unixtime"])
                         new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
                         new_reprompt_row.append(str(i))
                         prompt_arrays.append(new_reprompt_row)
 
     df_prompt = pd.DataFrame(prompt_arrays)
     if df_prompt.shape[0] > 0:
-        df_prompt.columns = ['Prompt_Type', 'Study_Mode', 'Initial_Prompt_Local_Time', 'Answer_Status', 'Prompt_Local_Time', 'UTC_Offset', "Reprompt_Num"]
+        df_prompt.columns = ['Prompt_Type', 'Study_Mode', 'Initial_Prompt_Local_Time', 'Answer_Status', "Actual_Prompt_Local_Time", 'First_Question_Completion_Unixtime', 'UTC_Offset', "Reprompt_Num"]
 
     return df_prompt
 
@@ -176,7 +181,7 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     df_reprompt.reset_index(drop=True, inplace=True)
     Prompt_Local_Time_list = []
     for idx in df_reprompt.index:
-        prompt_local_time_timezone = df_reprompt['Prompt_Local_Time'][idx]
+        prompt_local_time_timezone = df_reprompt['Actual_Prompt_Local_Time'][idx]
         prompt_local_time_timezone_split = prompt_local_time_timezone.split(" ")
         prompt_local_time_timezone_split_len = len(prompt_local_time_timezone_split)
         if prompt_local_time_timezone_split_len == 3:
@@ -187,7 +192,7 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
 
     converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
     prompt_dateobject_column = list(map(converter, Prompt_Local_Time_list))
-    df_reprompt['Prompt_Local_DateTime'] = prompt_dateobject_column
+    df_reprompt['Actual_Prompt_Local_DateTime'] = prompt_dateobject_column
 
     return df_reprompt
 
